Skip to contents

[Experimental]

Usage

app_user_create(
  pid = get_default_pid(),
  display_name,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

display_name

(character) The friendly nickname of the App User to create.

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with one row holding the new App User's metadata as columns, including the token to authenticate requests as this App User. The token is only returned at creation time.

Details

The only information required to create a new App User is its display name (called "Nickname" in the administration panel). When an App User is created, it is assigned no rights. To grant rights, assign the App User a Form Role with form_assignment_grant().

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

au <- app_user_create(display_name = "My App User")

au |> knitr::kable()
} # }