Usage
form_attachment_list(
pid = get_default_pid(),
fid = get_default_fid(),
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
- pid
The numeric ID of the project, e.g.: 2.
Default:
get_default_pid.Set default
pidthroughru_setup(pid="...").See
vignette("Setup", package = "ruODK").- fid
The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".
Default:
get_default_fid.Set default
fidthroughru_setup(fid="...").See
vignette("Setup", package = "ruODK").- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Value
A tibble with one row per expected Form attachment and the
columns name, type, exists, blob_exists, dataset_exists,
size, hash and updated_at, as far as Central returns them.
Column names are renamed from ODK Central's camelCase to
snake_case.
Details
This endpoint fetches the list of expected attachment files, and
tells whether the server holds each file or not, and a hash of the
file contents.
To modify an attachment, create a Draft.
The property datasetExists tells whether the attachment is a link
to a Dataset instead of an actual file.
See also
https://docs.getodk.org/central-api-form-management/#listing-form-attachments
Other form-management:
form_assignment_actors(),
form_assignment_grant(),
form_assignment_revoke(),
form_attachment_download(),
form_create(),
form_dataset_diff(),
form_delete(),
form_detail(),
form_draft_attachment_delete(),
form_draft_attachment_download(),
form_draft_attachment_link(),
form_draft_attachment_list(),
form_draft_attachment_upload(),
form_draft_create(),
form_draft_dataset_diff(),
form_draft_delete(),
form_draft_detail(),
form_draft_publish(),
form_draft_xlsx(),
form_draft_xml(),
form_link(),
form_list(),
form_restore(),
form_schema(),
form_schema_ext(),
form_update(),
form_version_attachment_download(),
form_version_attachment_list(),
form_version_detail(),
form_version_list(),
form_version_xlsx(),
form_version_xml(),
form_xlsx(),
form_xml(),
public_link_create(),
public_link_delete(),
public_link_detail(),
public_link_list(),
public_link_update()