Skip to contents

[Experimental]

Usage

form_draft_attachment_link(
  pid = get_default_pid(),
  fid = get_default_fid(),
  filename,
  dataset = TRUE,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

fid

The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".

Default: get_default_fid.

Set default fid through ru_setup(fid="...").

See vignette("Setup", package = "ruODK").

filename

(character) The name of the attachment, e.g. "people.csv" for a Dataset named "people".

dataset

(lgl) Link (TRUE) or unlink (FALSE) the Dataset.

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A list with the updated attachment's metadata as per the ODK Central API docs.

Details

This endpoint updates a Form Attachment's link to a Dataset. Linking only happens if the Attachment type is file and a Dataset with the exact name of the Attachment (excluding the .csv extension) exists in the Project. Letter case and spaces must match exactly. When a Dataset is linked, any attached file is removed. This endpoint requires ODK Central v2022.3 or later.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

fl <- form_list()
fid <- fl$fid[[1]]

form_draft_attachment_link(fid = fid, filename = "people.csv", dataset = TRUE)
} # }