Upload a Draft Form attachment.
Source:R/form_draft_attachment_upload.R
form_draft_attachment_upload.RdUsage
form_draft_attachment_upload(
pid = get_default_pid(),
fid = get_default_fid(),
filename,
file,
content_type = NULL,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
- pid
The numeric ID of the project, e.g.: 2.
Default:
get_default_pid.Set default
pidthroughru_setup(pid="...").See
vignette("Setup", package = "ruODK").- fid
The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".
Default:
get_default_fid.Set default
fidthroughru_setup(fid="...").See
vignette("Setup", package = "ruODK").- filename
(character) The name of the expected file slot, as given by
form_draft_attachment_list().- file
(character) Path to a local file whose bytes are uploaded to the expected file slot.
- content_type
(character) The MIME type sent as
Content-Typeheader. Default:NULL, which sends"application/octet-stream".- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Details
To upload a binary to an expected file slot, POST the binary to its
endpoint.
Supply a content_type if you have one.
If a Dataset is linked to this attachment, the upload unlinks and
replaces it with the uploaded file.
See also
https://docs.getodk.org/central-api-form-management/#uploading-a-draft-form-attachment
Other form-management:
form_assignment_actors(),
form_assignment_grant(),
form_assignment_revoke(),
form_attachment_download(),
form_attachment_list(),
form_create(),
form_dataset_diff(),
form_delete(),
form_detail(),
form_draft_attachment_delete(),
form_draft_attachment_download(),
form_draft_attachment_link(),
form_draft_attachment_list(),
form_draft_create(),
form_draft_dataset_diff(),
form_draft_delete(),
form_draft_detail(),
form_draft_publish(),
form_draft_xlsx(),
form_draft_xml(),
form_link(),
form_list(),
form_restore(),
form_schema(),
form_schema_ext(),
form_update(),
form_version_attachment_download(),
form_version_attachment_list(),
form_version_detail(),
form_version_list(),
form_version_xlsx(),
form_version_xml(),
form_xlsx(),
form_xml(),
public_link_create(),
public_link_delete(),
public_link_detail(),
public_link_list(),
public_link_update()
Examples
if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")
fl <- form_list()
fid <- fl$fid[[1]]
al <- form_draft_attachment_list(fid = fid)
form_draft_attachment_upload(
fid = fid,
filename = al$name[[1]],
file = "/path/to/file.csv"
)
} # }