Skip to contents

[Experimental]

Usage

form_version_xlsx(
  pid = get_default_pid(),
  fid = get_default_fid(),
  version,
  dest = NULL,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

fid

The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".

Default: get_default_fid.

Set default fid through ru_setup(fid="...").

See vignette("Setup", package = "ruODK").

version

(character) The version of the Form version being referenced. Pass ___ for a blank version.

dest

(character) The local file path to save the spreadsheet to. Default: NULL, which saves to a temporary .xlsx file.

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

The local file path the spreadsheet was saved to.

Details

If a Form Version was created with an Excel file (.xls or .xlsx), this function gets that file back. Versions created from XForms XML have no spreadsheet source, and Central answers those requests with 404.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

fl <- form_list()
fid <- fl$fid[[1]]

vl <- form_version_list(fid = fid)

xlsx <- form_version_xlsx(fid = fid, version = vl$version[[1]])

file.info(xlsx)$size
} # }