Usage
project_assignment_grant(
pid = get_default_pid(),
role_id,
actor_id,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries(),
odkc_version = get_default_odkc_version()
)Arguments
- pid
The numeric ID of the project, e.g.: 2.
Default:
get_default_pid.Set default
pidthroughru_setup(pid="...").See
vignette("Setup", package = "ruODK").- role_id
(character or numeric) The Role ID, typically the integer ID of the Role. A Role system name can also be supplied if the Role has one.
- actor_id
(numeric) The integer ID of the Actor.
- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
- odkc_version
The ODK Central version as a semantic version string (year.minor.patch), e.g. "2023.5.1". The version is shown on ODK Central's version page
/version.txt. Discard the "v".ruODKuses this parameter to adjust for breaking changes in ODK Central.Default:
get_default_odkc_versionor "2023.5.1" if unset.Set default
get_default_odkc_versionthroughru_setup(odkc_version="2023.5.1").See
vignette("Setup", package = "ruODK").
Details
Given a Role and an Actor, this endpoint assigns that Role to that Actor for this particular Project. No request body data is required. This endpoint requires ODK Central v0.5 or later.
See also
https://docs.getodk.org/central-api-project-management/#assigning-an-actor-to-a-project-role
Other project-management:
form_assignment_role_list(),
project_assignment_actors(),
project_assignment_revoke(),
project_create(),
project_delete(),
project_detail(),
project_enable_encryption(),
project_list(),
project_replace(),
project_update()