Skip to contents

[Experimental]

Usage

public_link_create(
  pid = get_default_pid(),
  fid = get_default_fid(),
  display_name,
  once = FALSE,
  properties = NULL,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

fid

The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".

Default: get_default_fid.

Set default fid through ru_setup(fid="...").

See vignette("Setup", package = "ruODK").

display_name

(character) The name of the Link, for keeping track of. This name shows on the Central administration website but not to survey respondents.

once

(lgl) Create an Enketo single-submission survey instead of a standard one. Default: FALSE.

properties

(list) An optional named list mapping pre-registered Actor Property names to string values. Default: NULL (not sent).

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with one row holding the new Link's metadata as columns as per the ODK Central API docs.

Details

To create a new Public Access Link to a Form, send at least a display_name for the resulting Actor. Set once to TRUE for a link that each respondent can only fill once. This setting is enforced by Enketo using local device tracking. An optional properties object sets pre-registered Actor Property values on the Link at creation time.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

fl <- form_list()

pl <- public_link_create(fid = fl$fid[[1]], display_name = "Survey link")

pl$token
} # }