Skip to contents

[Experimental]

Usage

role_detail(
  role_id,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

role_id

The numeric ID of the Role, or its system name.

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with one row holding the Role's metadata as columns as per the ODK Central API docs.

Details

Getting an individual Role reveals no additional information over listing all Roles, but allows direct lookup of a specific Role. The ID accepts the numeric ID of the Role, or a system name if the Role has one (e.g. admin for the Administrator Role). There are no authorization restrictions upon this endpoint.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

r <- role_detail("admin")

r$verbs
} # }