Skip to contents

[Experimental]

Usage

submission_csv(
  pid = get_default_pid(),
  fid = get_default_fid(),
  filter = NULL,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

fid

The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".

Default: get_default_fid.

Set default fid through ru_setup(fid="...").

See vignette("Setup", package = "ruODK").

filter

(character) An OData-style $filter query to filter the Submissions by. Only certain fields are available to reference. Default: NULL (not sent).

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with the root Submission table, one row per Submission.

Details

The ZIP export endpoints provide all possible related repeat table files, as well as the media files associated with the Submissions. To export just the root table (no repeat data nor media files), call this endpoint instead, which directly gives CSV data. An OData-style $filter query filters the Submissions. This endpoint requires ODK Central v1.1 or later.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

csv <- submission_csv()

csv |> knitr::kable()
} # }