Skip to contents

[Experimental]

Usage

submission_geodata(
  pid = get_default_pid(),
  fid = get_default_fid(),
  filter = NULL,
  limit = NULL,
  fieldpath = NULL,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

fid

The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".

Default: get_default_fid.

Set default fid through ru_setup(fid="...").

See vignette("Setup", package = "ruODK").

filter

(character) An OData-style $filter query to filter the Submissions by. Default: NULL (not sent).

limit

(numeric) The maximum number of Submissions to extract geoinformation from. Default: NULL (not sent).

fieldpath

(character) The field to extract geoinformation from. At most one field can be given. Default: NULL (the first geofield outside any repeat group).

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A list with the GeoJSON FeatureCollection as returned by Central: type and features with geometry and properties per Submission.

Details

This endpoint returns Submissions' geodata, one Form field per Submission, in GeoJSON format. If no particular field path is supplied, the first non-repeat geopoint, geotrace or geoshape field is used. No particular ordering is implied. An OData-style $filter query filters the Submissions.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

sl <- submission_list()

g <- submission_geodata()

g$type
# > "FeatureCollection"
} # }