Skip to contents

[Experimental]

Usage

submission_review(
  iid,
  pid = get_default_pid(),
  fid = get_default_fid(),
  review_state = "",
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

iid

The instance_id, a UUID, as returned by submission_list.

pid

The numeric ID of the project, e.g.: 2.

Default: get_default_pid.

Set default pid through ru_setup(pid="...").

See vignette("Setup", package = "ruODK").

fid

The alphanumeric form ID, e.g. "build_Spotlighting-0-8_1559885147".

Default: get_default_fid.

Set default fid through ru_setup(fid="...").

See vignette("Setup", package = "ruODK").

review_state

(character) The new review state of the Submission. One of "approved", "hasIssues" or "rejected".

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A list with the reviewed Submission's metadata as per the ODK Central API docs. Top level list elements are renamed from ODK's camelCase to snake_case.

Details

Currently, the only updatable metadata on a Submission is its reviewState. To update the Submission data itself, see submission_update().

Starting with Version 2022.3, changing the reviewState of a Submission to approved can create an Entity in a Dataset if the corresponding Form maps Dataset Properties to Form Fields.

This function records a review decision on a Submission. Clearing the review state back to unreviewed (received) is not supported by this function.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

sl <- submission_list()

s <- submission_review(sl$instance_id[[1]], review_state = "approved")

s$review_state
# > "approved"
} # }