Skip to contents

[Experimental]

Usage

user_create(
  email,
  password = NULL,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

email

(character) The email address of the User account to create.

password

(character) If provided, the User account is created with this password. Default: NULL (the User sets the password later).

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with one row holding the new User's metadata as columns.

Details

All that is required to create a new User is an email address. That email address will receive a message instructing the new User on how to claim the new account and set a password. Optionally, a password may also be supplied as a part of this request. If it is, the account is immediately usable with the given credentials. Users are not able to do anything upon creation besides log in and change their own profile information. To allow Users to perform useful actions, assign them one or more Roles.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

u <- user_create(email = "new.user@example.com")

u |> knitr::kable()
} # }