Skip to contents

[Experimental]

Usage

user_detail(
  actor_id = "current",
  extended = FALSE,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

actor_id

The integer ID of the User, or "current" for the authenticated User. Default: "current".

extended

(lgl) If TRUE, request extended metadata with the X-Extended-Metadata header. Only used with actor_id = "current". Default: FALSE.

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with one row holding the User's metadata as columns as per the ODK Central API docs.

Details

Supply the integer ID to get the User with that ID, or the text current for the currently authenticated User. With current, extended metadata can be requested: the verbs the authenticated Actor can perform server-wide, and the User's preferences.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

me <- user_detail()

me$display_name
} # }