Skip to contents

[Experimental]

Usage

user_update(
  actor_id,
  display_name = NULL,
  email = NULL,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

actor_id

(numeric) The integer ID of the User.

display_name

(character) The friendly display name to associate with this User. Default: NULL (left unchanged).

email

(character) The email address to associate with this User. Default: NULL (left unchanged).

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A tibble with one row holding the User's metadata as columns.

Details

JSON data can be patched to update User details. The display name sets the friendly name the web interface uses to refer to the User. The email sets the email address associated with the account. When User details are updated, the updatedAt field is updated automatically.

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

ul <- user_list()

u <- user_update(actor_id = ul$id[[1]], display_name = "New Name")

u |> knitr::kable()
} # }