Skip to contents

[Experimental]

Usage

user_update_password(
  actor_id,
  old_password,
  new_password,
  url = get_default_url(),
  un = get_default_un(),
  pw = get_default_pw(),
  retries = get_retries()
)

Arguments

actor_id

(numeric) The integer ID of the User.

old_password

(character) The User's current password.

new_password

(character) The new password the User wishes to set.

url

The ODK Central base URL without trailing slash.

Default: get_default_url.

Set default url through ru_setup(url="...").

See vignette("Setup", package = "ruODK").

un

The ODK Central username (an email address). Default: get_default_un. Set default un through ru_setup(un="..."). See vignette("Setup", package = "ruODK").

pw

The ODK Central password. Default: get_default_pw. Set default pw through ru_setup(pw="..."). See vignette("Setup", package = "ruODK").

retries

The number of attempts to retrieve a web resource.

This parameter is given to RETRY(times = retries).

Default: 3.

Value

A list with a single element success (TRUE) as per the ODK Central API docs.

Details

To directly update a User password, the User's intention must be reproven by supplying the old password alongside the new password. To initiate an email-based password reset process instead, see user_reset_password().

Examples

if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")

ul <- user_list()

user_update_password(
  actor_id = ul$id[[1]],
  old_password = "old.password",
  new_password = "new.password"
)
# > $success
# > [1] TRUE
} # }