Usage
app_user_create(
pid = get_default_pid(),
display_name,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
- pid
The numeric ID of the project, e.g.: 2.
Default:
get_default_pid.Set default
pidthroughru_setup(pid="...").See
vignette("Setup", package = "ruODK").- display_name
(character) The friendly nickname of the App User to create.
- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Value
A tibble with one row holding the new App User's metadata as
columns, including the token to authenticate requests as this App
User.
The token is only returned at creation time.
Details
The only information required to create a new App User is its display
name (called "Nickname" in the administration panel).
When an App User is created, it is assigned no rights.
To grant rights, assign the App User a Form Role with
form_assignment_grant().
See also
https://docs.getodk.org/central-api-accounts-and-users/#creating-a-new-app-user
Other user-management:
app_user_delete(),
app_user_list(),
assignment_actors(),
assignment_grant(),
assignment_list(),
assignment_revoke(),
form_assignment_list(),
project_assignment_list(),
role_detail(),
role_list(),
user_create(),
user_delete(),
user_detail(),
user_list(),
user_preference_project_delete(),
user_preference_project_set(),
user_preference_site_delete(),
user_preference_site_set(),
user_reset_password(),
user_update(),
user_update_password()
Examples
if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")
au <- app_user_create(display_name = "My App User")
au |> knitr::kable()
} # }