Usage
entitylist_create(
pid = get_default_pid(),
name = "",
approval_required = FALSE,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries(),
odkc_version = get_default_odkc_version(),
orders = get_default_orders(),
tz = get_default_tz()
)Arguments
- pid
The numeric ID of the project, e.g.: 2.
Default:
get_default_pid.Set default
pidthroughru_setup(pid="...").See
vignette("Setup", package = "ruODK").- name
(character) The desired name of the Entity List. The name must follow the same rules as XML identifiers and must not start with
.or__.- approval_required
(lgl) Control whether a Submission should be approved before an Entity is created from it. Default:
FALSE.- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
- odkc_version
The ODK Central version as a semantic version string (year.minor.patch), e.g. "2023.5.1". The version is shown on ODK Central's version page
/version.txt. Discard the "v".ruODKuses this parameter to adjust for breaking changes in ODK Central.Default:
get_default_odkc_versionor "2023.5.1" if unset.Set default
get_default_odkc_versionthroughru_setup(odkc_version="2023.5.1").See
vignette("Setup", package = "ruODK").- orders
(vector of character) Orders of datetime elements for lubridate.
Default:
c("YmdHMS", "YmdHMSz", "Ymd HMS", "Ymd HMSz", "Ymd", "ymd").- tz
A timezone to convert dates and times to.
Read
vignette("setup", package = "ruODK")to learn howruODK's timezone can be set globally or per function.
Value
A list of lists following the exact format and naming of the API
response for entitylist_detail.
Details
You can create a Dataset with a specific name within a Project. This Dataset can then be populated with Entities via the API or via Forms and Submissions, and then used by other Forms. This endpoint allows a Dataset to be created programmatically without an input form.
The name of a Dataset is case-sensitive in that it will keep the capitalization provided (e.g. "Trees"). But Central will not allow a second Dataset with the same name but different capitalization to be created (e.g. "trees" when "Trees" already exists).
By default, the Dataset will have no properties, but each Entity will have a label and a unique ID (uuid).
This creates an empty Entity List.
Add properties with the Dataset properties endpoint.
Add Entities with entity_create().
Or publish a Form that defines the Entity List schema.
See also
https://docs.getodk.org/central-api-dataset-management/#creating-datasets
Other entity-management:
entity_audits(),
entity_bulk_delete(),
entity_bulk_restore(),
entity_changes(),
entity_create(),
entity_creators(),
entity_delete(),
entity_detail(),
entity_geodata(),
entity_geojson(),
entity_list(),
entity_restore(),
entity_update(),
entity_versions(),
entitylist_delete(),
entitylist_detail(),
entitylist_download(),
entitylist_list(),
entitylist_property_create(),
entitylist_property_delete(),
entitylist_trash_download(),
entitylist_update(),
odata_entitylist_data_get(),
odata_entitylist_metadata_get(),
odata_entitylist_service_get()