Add a property to an Entity List.
Source:R/entitylist_property_create.R
entitylist_property_create.RdUsage
entitylist_property_create(
pid = get_default_pid(),
did = "",
property = "",
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries(),
odkc_version = get_default_odkc_version(),
orders = get_default_orders(),
tz = get_default_tz()
)Arguments
- pid
The numeric ID of the project, e.g.: 2.
Default:
get_default_pid.Set default
pidthroughru_setup(pid="...").See
vignette("Setup", package = "ruODK").- did
(chr) The name of the Entity List, internally called Dataset. The function will error if this parameter is not given. Default: "".
- property
(character) The desired name of the Property.
- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
- odkc_version
The ODK Central version as a semantic version string (year.minor.patch), e.g. "2023.5.1". The version is shown on ODK Central's version page
/version.txt. Discard the "v".ruODKuses this parameter to adjust for breaking changes in ODK Central.Default:
get_default_odkc_versionor "2023.5.1" if unset.Set default
get_default_odkc_versionthroughru_setup(odkc_version="2023.5.1").See
vignette("Setup", package = "ruODK").- orders
(vector of character) Orders of datetime elements for lubridate.
Default:
c("YmdHMS", "YmdHMSz", "Ymd HMS", "Ymd HMSz", "Ymd", "ymd").- tz
A timezone to convert dates and times to.
Read
vignette("setup", package = "ruODK")to learn howruODK's timezone can be set globally or per function.
Details
Creates a new Property with a specified name in the Dataset.
The name of a Property is case-sensitive in that it will keep the
capitalization provided (e.g. "Firstname").
But Central will not allow another Property with the same name but
different capitalization to be created
(e.g. "FIRSTNAME" when "Firstname" already exists).
Property names follow the same rules as form field names (valid XML
identifiers) and cannot use the reserved names of name or label, or
begin with the reserved prefix __.
See also
https://docs.getodk.org/central-api-dataset-management/#adding-properties
Other entity-management:
entity_audits(),
entity_bulk_delete(),
entity_bulk_restore(),
entity_changes(),
entity_create(),
entity_creators(),
entity_delete(),
entity_detail(),
entity_geodata(),
entity_geojson(),
entity_list(),
entity_restore(),
entity_update(),
entity_versions(),
entitylist_create(),
entitylist_delete(),
entitylist_detail(),
entitylist_download(),
entitylist_list(),
entitylist_property_delete(),
entitylist_trash_download(),
entitylist_update(),
odata_entitylist_data_get(),
odata_entitylist_metadata_get(),
odata_entitylist_service_get()