Usage
role_detail(
role_id,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
- role_id
The numeric ID of the Role, or its system name.
- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Details
Getting an individual Role reveals no additional information over
listing all Roles, but allows direct lookup of a specific Role.
The ID accepts the numeric ID of the Role, or a system name if the
Role has one (e.g. admin for the Administrator Role).
There are no authorization restrictions upon this endpoint.
See also
https://docs.getodk.org/central-api-accounts-and-users/#getting-role-details
Other user-management:
app_user_create(),
app_user_delete(),
app_user_list(),
assignment_actors(),
assignment_grant(),
assignment_list(),
assignment_revoke(),
form_assignment_list(),
project_assignment_list(),
role_list(),
user_create(),
user_delete(),
user_detail(),
user_list(),
user_preference_project_delete(),
user_preference_project_set(),
user_preference_site_delete(),
user_preference_site_set(),
user_reset_password(),
user_update(),
user_update_password()