Usage
user_reset_password(
email,
invalidate = FALSE,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
(character) The email address of the User account whose password is to be reset.
- invalidate
(lgl) If
TRUE, the User's current password is immediately invalidated, regardless of whether the reset is completed. This requires an authenticated User with permission to do this. Default:FALSE.- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Details
Anybody can initiate a reset of any User's password. An email is sent with instructions on how to complete the password reset; it contains a token that is required to complete the process. If the email address provided does not match any User in the system, that address is still sent an email informing them of the attempt and that no account was found.
See also
https://docs.getodk.org/central-api-accounts-and-users/#initating-a-password-reset
Other user-management:
app_user_create(),
app_user_delete(),
app_user_list(),
assignment_actors(),
assignment_grant(),
assignment_list(),
assignment_revoke(),
form_assignment_list(),
project_assignment_list(),
role_detail(),
role_list(),
user_create(),
user_delete(),
user_detail(),
user_list(),
user_preference_project_delete(),
user_preference_project_set(),
user_preference_site_delete(),
user_preference_site_set(),
user_update(),
user_update_password()