Usage
user_update(
actor_id,
display_name = NULL,
email = NULL,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
- actor_id
(numeric) The integer ID of the User.
- display_name
(character) The friendly display name to associate with this User. Default:
NULL(left unchanged).(character) The email address to associate with this User. Default:
NULL(left unchanged).- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Details
JSON data can be patched to update User details. The display name sets the friendly name the web interface uses to refer to the User. The email sets the email address associated with the account. When User details are updated, the updatedAt field is updated automatically.
See also
https://docs.getodk.org/central-api-accounts-and-users/#modifying-a-user
Other user-management:
app_user_create(),
app_user_delete(),
app_user_list(),
assignment_actors(),
assignment_grant(),
assignment_list(),
assignment_revoke(),
form_assignment_list(),
project_assignment_list(),
role_detail(),
role_list(),
user_create(),
user_delete(),
user_detail(),
user_list(),
user_preference_project_delete(),
user_preference_project_set(),
user_preference_site_delete(),
user_preference_site_set(),
user_reset_password(),
user_update_password()