Usage
user_update_password(
actor_id,
old_password,
new_password,
url = get_default_url(),
un = get_default_un(),
pw = get_default_pw(),
retries = get_retries()
)Arguments
- actor_id
(numeric) The integer ID of the User.
- old_password
(character) The User's current password.
- new_password
(character) The new password the User wishes to set.
- url
The ODK Central base URL without trailing slash.
Default:
get_default_url.Set default
urlthroughru_setup(url="...").See
vignette("Setup", package = "ruODK").- un
The ODK Central username (an email address). Default:
get_default_un. Set defaultunthroughru_setup(un="..."). Seevignette("Setup", package = "ruODK").- pw
The ODK Central password. Default:
get_default_pw. Set defaultpwthroughru_setup(pw="..."). Seevignette("Setup", package = "ruODK").- retries
The number of attempts to retrieve a web resource.
This parameter is given to
RETRY(times = retries).Default: 3.
Details
To directly update a User password, the User's intention must be reproven
by supplying the old password alongside the new password.
To initiate an email-based password reset process instead, see
user_reset_password().
See also
https://docs.getodk.org/central-api-accounts-and-users/#directly-updating-a-user-password
Other user-management:
app_user_create(),
app_user_delete(),
app_user_list(),
assignment_actors(),
assignment_grant(),
assignment_list(),
assignment_revoke(),
form_assignment_list(),
project_assignment_list(),
role_detail(),
role_list(),
user_create(),
user_delete(),
user_detail(),
user_list(),
user_preference_project_delete(),
user_preference_project_set(),
user_preference_site_delete(),
user_preference_site_set(),
user_reset_password(),
user_update()
Examples
if (FALSE) { # \dontrun{
# See vignette("setup") for setup and authentication options
# ruODK::ru_setup(svc = "....svc", un = "me@email.com", pw = "...")
ul <- user_list()
user_update_password(
actor_id = ul$id[[1]],
old_password = "old.password",
new_password = "new.password"
)
# > $success
# > [1] TRUE
} # }